<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Σχετικά </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Έκδοση</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Δημιουργός</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Δωρεά</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Επικοινωνία</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Άδεια χρήσης: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Εργαλείο λήψης στιγμιότυπων και σημειώσεων</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Συντόμευση</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Καθαρισμός</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Σύλληψη</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Συμπερίληψη του δρομέα</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Καθυστέρηση</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>δ</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Λειτουργία σύλληψης</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Προβολή της εικόνας σε καρφιτσωμένο παράθυρο</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Αντιγραφή της εικόνας στο πρόχειρο</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Αποστολή εικόνας</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Άνοιγμα του γονικού καταλόγου της εικόνας</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Αποθήκευση εικόνας</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Απόκρυψη του κύριου παραθύρου</translation>
    </message>
    <message>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will make the shortcut
available even when ksnip has no focus.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Ρυθμίσεις ενεργειών</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ενέργεια</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Απαιτείται μια εικόνα υδατογραφήματος</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Παρακαλώ προσθέστε μια εικόνα υδατογραφήματος από τις Επιλογές &gt; Ρυθμίσεις &gt; Σχολιαστής &gt; Ενημέρωση</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Εξομάλυνση των γραμμών σχεδίασης</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Όταν είναι ενεργοποιημένο, εξομαλύνει την χάραξη
της γραφίδας και των σημαδευτών μετά το πέρας της ενέργειας.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Συντελεστής εξομάλυνσης</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Η αύξηση της του συντελεστή εξομάλυνσης θα μειώσει
την ακρίβεια της γραφίδας και των σημαδευτών αλλά
η χάραξη θα φαίνεται πιο ομαλοποιημένη.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Ρυθμίσεις σχολιαστή</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Απομνημόνευση της επιλογής του εργαλείου σημειώσεων και φόρτωση στην εκκίνηση</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Εναλλαγή στο εργαλείο επιλογής μετά τον σχεδιασμό του αντικειμένου</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Μια αλλαγή στον αρχικό αριθμό αλλάζει όλα τα αριθμημένα αντικείμενα</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Απενεργοποιώντας αυτήν την επιλογή, οι αλλαγές στον αρχικό αριθμό
επηρεάζουν μόνον τα νέα αντικείμενα και όχι τα υπάρχοντα.
Η απενεργοποίηση της επιλογής επιτρέπει διπλότυπους αριθμούς.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Χρώμα του καμβά</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Το προκαθορισμένο χρώμα παρασκηνίου του καμβά για την περιοχή σχολιασμού.
Η αλλαγή του χρώματος επηρεάζει μόνον τις νέες περιοχές σχολιασμού.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Επιλογή του αντικειμένου μετά τον σχεδιασμό</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Αν αυτή η επιλογή είναι ενεργοποιημένη, το αντικείμενο επιλέγεται αμέσως
μετά την δημιουργία του και επιτρέπει την επεξεργασία των παραμέτρων.</translation>
    </message>
    <message>
        <source>Show Controls Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Controls Widget contains the Undo/Redo,
Crop, Scale, Rotate and Modify Canvas buttons.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Λήψη στιγμιότυπου κατά την έναρξη στην προκαθορισμένη λειτουργία</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Τεχνοτροπία της εφαρμογής</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Ορίζει την τεχνοτροπία εμφάνισης της εφαρμογής.
Για να ληφθούν υπόψιν οι αλλαγές, απαιτείται επανεκκίνηση του ksnip.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Ρυθμίσεις της εφαρμογής</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Αυτόματη αντιγραφή των νέων συλλήψεων στο πρόχειρο</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Χρήση καρτελών</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Η αλλαγή απαιτεί επανεκκίνηση.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Μοναδική εκτέλεση του ksnip</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Απόκρυψη της γραμμής καρτελών κατά την χρήση μιας καρτέλας.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Ενεργοποιώντας αυτήν την επιλογή θα επιτρέπεται μόνο μια υπηρεσία του ksnip,
όλες οι υπόλοιπες θα εκτελεστούν όταν ολοκληρωθεί η πρώτη.
Η αλλαγή αυτής της επιλογής απαιτεί
επανεκκίνηση όλων των υπηρεσιών.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Απομνημόνευση της θέσης του κύριου παραθύρου κατά την μετακίνηση και φόρτωση στην εκκίνηση</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Αυτόματη απόκρυψη των καρτελών</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Αυτόματη απόκρυψη αποβάθρων</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Απόκρυψη της εργαλειοθήκης και των ρυθμίσεων σχολιασμού κατά την εκκίνηση.
Χρησιμοποιήστε το πλήκτρο Tab για εναλλαγή της ορατότητας των αποβάθρων.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Αυτόματη κλιμάκωση βάσει του περιεχομένου</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Αυτόματη αλλαγή μεγέθους του κυρίως παραθύρου για προσαρμογή στο περιεχόμενο της εικόνας.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resize delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp directory used for storing temporary images that are
going to be deleted after ksnip closes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Περιήγηση</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Οι συνεισφέροντες:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Ισπανική μετάφραση</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Ολλανδική μετάφραση</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Ρωσική μετάφραση</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Νορβηγική μετάφραση (Bokmål)</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Γαλλική μετάφραση</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Πολωνική μετάφραση</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Υποστήριξη Snap &amp; Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Οι δημιουργοί:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Προειδοποίηση - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Η σύλληψη %1%2%3 έχει τροποποιηθεί.
Θέλετε να την αποθηκεύσετε;</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Νέα</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Σχεδιασμός μιας ορθογώνιας περιοχής με το ποντίκι</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Σύλληψη ολόκληρης της οθόνης συμπεριλαμβανομένου όλων των οθονών</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Σύλληψη της οθόνης που βρίσκεται ο δρομέας του ποντικιού</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Σύλληψη του παραθύρου που έχει την εστίαση</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Σύλληψη του παραθύρου κάτω από τον δρομέα του ποντικιού</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Σύλληψη στιγμιότυπου της τελευταίας επιλεγμένης ορθογώνιας περιοχής</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Χρησιμοποιήστε την πύλη στιγμιότυπου για την λήψη ενός στιγμιότυπου</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Κοινότητα</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Αναφορές σφαλμάτων</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Αποτυχία αντιγραφής στο πρόχειρο</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Αποτυχία αντιγραφής στο πρόχειρο ως εικόνα κωδικοποιημένη σε base64.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Αντιγράφηκε στο πρόχειρο</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Αντιγραφή στο πρόχειρο ως εικόνα κωδικοποιημένη σε base64.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Διαγραφή της εικόνας</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Το αντικείμενο %1 δια διαγραφεί.
Θέλετε να συνεχίσετε;</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Οι δωρεές είναι ευπρόσδεκτες</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Δωρεά</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Προσθήκη νέων ενεργειών με το πλήκτρο &quot;Προσθήκη&quot; της καρτέλας.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Ορθογώνια περιοχή</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Τελευταία ορθογώνια περιοχή</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Πλήρης οθόνη (Όλες οι οθόνες)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Τρέχουσα οθόνη</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Ενεργό παράθυρο</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Παράθυρο κάτω από τον δρομέα</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Πύλη στιγμιότυπου</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Επιτυχής αποστολή</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Αδύνατη η προσωρινή αποθήκευση της εικόνας για αποστολή.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Αδύνατη η εκκίνηση της διεργασίας· ελέγξτε την διαδρομή και τις άδειες.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Η διεργασία κατέρρευσε</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Λήξη χρονικού ορίου της διεργασίας.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Σφάλμα ανάγνωσης της διεργασίας.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Σφάλμα εγγραφής της διεργασίας.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Σφάλμα ιστού, ελέγξτε την έξοδο του τερματικού.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Αποτυχία αποστολής</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Η μακροεντολή έγγραψε στο StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Ενεργοποίηση των καθολικών συντομεύσεων</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Σύλληψη ορθογώνιας περιοχής</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Σύλληψη πλήρους οθόνης</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Σύλληψη τρέχουσας οθόνης</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Σύλληψη ενεργού παραθύρου</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Σύλληψη παραθύρου κάτω από τον δρομέα</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Πλήκτρα καθολικών συντομεύσεων</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Σύλληψη της τελευταίας ορθογώνιας περιοχής</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Καθαρισμός</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Σύλληψη μέσω της πύλης</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Οι συντομεύσεις υποστηρίζονται προς το παρόν μόνο για Windows και X11.
Απενεργοποιώντας αυτήν την επιλογή οι συντομεύσεις θα έχουν ισχύ μόνο στο ksnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Σύλληψη του δρομέα του ποντικιού στο στιγμιότυπο</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Αν θα πρέπει να είναι ορατός ο δρομέας
του ποντικιού στο στιγμιότυπο.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Σύλληψη εικόνας</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Η ενσωμάτωση σε γενικό Wayland που χρησιμοποιεί
XDG-DESKTOP-PORTAL διαχειρίζεται την κλιμάκωση
της εικόνας διαφορετικά. Η ενεργοποίηση αυτής της επιλογής
θα προσδιορίσει την τρέχουσα κλιμάκωση της εικόνας
και θα την εφαρμόσει στην στο στιγμιότυπο στο ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>Το GNOME και το KDE Plasma υποστηρίζουν τα δικά τους Wayland
και γενικού XDG-DESKTOP-PORTAL στιγμιότυπα. Ενεργοποιώντας
αυτήν την επιλογή θα εξαναγκάσει το KDE Plasma και το GNOME
να χρησιμοποιήσουν τα στιγμιότυπα XDG-DESKTOP-PORTAL.
Η αλλαγή της επιλογής αυτής απαιτεί την επανεκκίνηση του ksnip.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Εμφάνιση του κύριου παραθύρου μετά την σύλληψη του στιγμιότυπου</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Απόκρυψη του κύριου παραθύρου κατά την σύλληψη του στιγμιότυπου</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Απόκρυψη του κύριου παραθύρου κατά την σύλληψη ενός στιγμιότυπου.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Εμφάνιση του κύριου παραθύρου μετά την σύλληψη ενός στιγμιότυπου
όταν το κύριο παράθυρο είναι καταχωνιασμένο ή ελαχιστοποιημένο.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Implicit capture delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This delay is used when no delay was selected in
the UI, it allows ksnip to hide before taking
a screenshot. This value is not applied when
ksnip was already minimized. Reducing this value
can have the effect that ksnip&apos;s main window is
visible on the screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Ιστορικό Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Χρονοσφραγίδα</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Σύνδεσμος</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Διαγραφή δεσμού</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Η αποστολή στο Imgur ολοκληρώθηκε!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Λήψη νέου αδειοδοτικού, προσπάθεια αποστολής ξανά…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Το αδειοδοτικό του Imgur έληξε, γίνεται αίτηση νέας αδειοδότησης…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Εξαναγκασμός ανώνυμης αποστολής</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Αντιγραφή πάντα του δεσμού Imgur στο πρόχειρο</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Αναγνωριστικό πελάτη</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Μυστικό πελάτη</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Εισαγάγετε το PIN του Imgur το οποίο θα χρησιμοποιηθεί για την αδειοδότηση.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Λήψη PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Λήψη αδειοδοτικού</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Ιστορικό Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Αποστολέας Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Αναμονή του imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Το αδειοδοτικό του imgur.com ενημερώθηκε επιτυχώς.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Σφάλμα στην ενημέρωση της αδειοδότησης του imgur.com.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Μετά την αποστολή άνοιγμα του δεσμού Imgur στον προκαθορισμένο φυλλομετρητή</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Απευθείας δεσμός της εικόνας</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Βασικό Url:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Το βασικό url που θα χρησιμοποιηθεί για την επικοινωνία με το Imgur.
Για να ληφθεί υπόψιν η αλλαγή απαιτείται επανεκκίνηση.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Εκκαθάριση αδειοδοτικού</translation>
    </message>
    <message>
        <source>Upload title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload description:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Αδύνατο το άνοιγμα της εικόνας</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Αδύνατο το άνοιγμα της εικόνας από την διαδρομή %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Νέα</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Καθυστέρηση σε δευτερόλεπτα μεταξύ της
ενεργοποίησης και της σύλληψης του στιγμιότυπου.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>δ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Αποθήκευση της σύλληψης στο σύστημα αρχείων</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Αντιγραφή της σύλληψης στο πρόχειρο</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Εργαλεία</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Αναίρεση</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Επανάληψη</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Περικοπή</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Περικοπή της σύλληψης της οθόνης</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Μη αποθηκευμένο</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Αποστολή</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Εκτύπωση</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Ανοίγει τον διάλογο εκτύπωσης και προσφέρει την επιλογή εκτύπωσης της εικόνας</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Προεπισκόπηση εκτύπωσης</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Ανοίγει τον διάλογο προεπισκόπησης της εκτύπωσης από όπου μπορεί να γίνει αλλαγή του προσανατολισμού</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Κλιμάκωση</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>Επιλο&amp;γές</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Προσθήκη υδατογραφήματος</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Προσθήκη υδατογραφήματος στο στιγμιότυπο. Υποστηρίζεται και η πολλαπλή προσθήκη.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Αρχείο</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Αδύνατη η εμφάνιση της εικόνας</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Αποθήκευση ως...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Επικόλληση</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Ενσωματωμένη επικόλληση</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Καρφίτσωμα</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Καρφίτσωμα του στιγμιότυπου στο προσκήνιο σε άνευ πλαισίου παράθυρα</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Αναμενόταν μια εικόνα αλλά δεν παρείχατε κάποια.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Αντιγραφή της διαδρομής</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Άνοιγμα καταλόγου</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Προβολή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Άνοιγμα εικόνων</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Εμφάνιση αποβάθρας</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Απόκρυψη αποβάθρας</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Αντιγραφή ως URI δεδομένων</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Άνοιγμα &amp;πρόσφατου</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Τροποποίηση του καμβά</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Αποστολή της σύλληψης του ενεργοποιητή προς μια εξωτερική πηγή</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Αντιγραφή της σύλληψης του ενεργοποιητή στο πρόχειρο του συστήματος</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Κλιμάκωση εικόνας</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Περιστροφή</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Περιστροφή εικόνας</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Ενέργειες</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OCR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Αποθήκευση ως</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Άνοιγμα καταλόγου</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Αντιγραφή της διαδρομής</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Σύλληψη</translation>
    </message>
</context>
<context>
    <name>OcrWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Κλείσιμο των άλλων</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Κλείσιμο όλων</translation>
    </message>
</context>
<context>
    <name>PinWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginsSettings</name>
    <message>
        <source>Search Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">Προεπιλογή</translation>
    </message>
    <message>
        <source>The directory where the plugins are located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Περιήγηση</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Όνομα</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">Έκδοση</translation>
    </message>
    <message>
        <source>Detect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProcessIndicator</name>
    <message>
        <source>Processing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Η εικόνα μετονομάστηκε</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Η μετονομασία της εικόνας απέτυχε</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Μετονομασία της εικόνας</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Νέο όνομα αρχείου:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Αποθήκευση ως</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Όλα τα αρχεία</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Η εικόνα αποθηκεύτηκε</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Η αποθήκευση της εικόνας απέτυχε</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Αυτόματη αποθήκευση των νέων λήψεων στην προκαθορισμένη τοποθεσία</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Προτροπή για αποθήκευση πριν την απόρριψη των μη αποθηκευμένων αλλαγών</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Απομνημόνευση του τελευταίου καταλόγου αποθήκευσης</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Όταν είναι ενεργοποιημένο απομνημονεύεται ο τελευταία
χρησιμοποιούμενος κατάλογος για χρήση στις επόμενες αποθηκεύσεις.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Τοποθεσία και όνομα αρχείου αποθήκευσης της σύλληψης</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Οι υποστηριζόμενοι τύποι είναι JPG, PNG και BMP. Αν δεν ορίσετε τον τύπο θα χρησιμοποιηθεί εξ ορισμού το PNG.
Το όνομα αρχείου μπορεί να περιέχει τα ακόλουθα σύμβολα υποκατάστασης:
- $Y, $M, $D για την ημερομηνία, $h, $m, $s για την ώρα, ή $T για την ώρα σε μορφή hhmmss.
- Πολλαπλές ακολουθίες # για τον μετρητή. Με χρήση των #### θα λάβετε 0001, και στην επόμενη σύλληψη θα γίνει 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Περιήγηση</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Αποθήκευση των ρυθμίσεων</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Τοποθεσία αποθήκευσης της σύλληψης</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Συντελεστής</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Ποιότητα αποθήκευσης</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Ορίστε 0 για να αποκτήσετε μικρά συμπιεσμένα αρχεία, 100 για μεγάλα μη συμπιεσμένα αρχεία.
Το πλήρες εύρος δεν υποστηρίζεται από όλους τους τύπους εικόνας· το JPEG το υποστηρίζει.</translation>
    </message>
    <message>
        <source>Overwrite file with same name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Αντιγραφή της εξόδου της μακροεντολής στο πρόχειρο</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Μακροεντολή:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Η διαδρομή της μακροεντολής που θα εκτελεστεί για την αποστολή.
Κατά την αποστολή η μακροεντολή θα εκτελεστεί με μοναδικό όρισμα την διαδρομή ενός προσωρινού αρχείου png.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Περιήγηση</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Μακροεντολή αποστολής</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Επιλογή μακροεντολής αποστολής</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Διακοπή όταν η μακροεντολή αποστολής γράφει στο StdErr</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Σημειώνει την αποστολή ως αποτυχημένη όταν η μακροεντολή γράφει στο StdErr.
Χωρίς αυτήν την ρύθμιση τα τυχόν σφάλματα της μακροεντολής θα περάσουν απαρατήρητα.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Φίλτρο:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Κανονική έκφραση. Αντιγραφή στο πρόχειρο μόνο ό,τι ταιριάζει στην κανονική έκφραση.
Αν δεν οριστεί κάποιο φίλτρο θα αντιγραφούν όλες οι γραμμές.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Σύλληψη εικόνας</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Αποστολέας Imgur</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Σχολιαστής</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Πλήκτρα συντομεύσεων</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Αποστολέας</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Μακροεντολή αποστολής</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Αυτοκόλλητα</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Περιοχή σύλληψης</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Εικονίδιο πλαισίου συστήματος</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Υδατογράφημα</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Ενέργειες</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search Settings...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Αλλαγή μεγέθους του επιλεγμένου ορθογωνίου χρησιμοποιώντας τις λαβές ή μετακίνηση με σύρσιμο της επιλογής.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Χρησιμοποιήστε τα βελάκια για να μετακινήσετε την επιλογή.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Χρησιμοποιήστε τα βελάκια κρατώντας πατημένο το πλήκτρο CTRL για να μετακινήσετε την πάνω αριστερά λαβή.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Χρησιμοποιήστε τα βελάκια κρατώντας πατημένο το πλήκτρο ALT για να μετακινήσετε την κάτω δεξιά λαβή.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Αυτό το μήνυμα μπορεί να απενεργοποιηθεί από τις ρυθμίσεις.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Κλικ και σύρσιμο για να επιλέξετε μια ορθογώνια περιοχή ή πιέστε ESC για εγκατάλειψη.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Αφού πραγματοποιήσετε την επιλογή, κρατήστε πατημένο το CTRL για να αλλάξετε το μέγεθός της.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Αφού πραγματοποιήσετε την επιλογή, κρατήστε πατημένο το CTRL για να αποτρέψετε την αλλαγή του μεγέθους της.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>Η ενέργεια θα ακυρωθεί μετά από 60 δευτ. αν δεν πραγματοποιηθεί κάποια επιλογή.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Αυτό το μήνυμα μπορεί να απενεργοποιηθεί από τις ρυθμίσεις.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Πάγωμα της οθόνης κατά την σύλληψη</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Όταν είναι ενεργοποιημένο, το παρασκήνιο θα είναι παγωμένο
κατά την επιλογή της ορθογώνιας περιοχής. Επίσης αλλάζει
την συμπεριφορά των στιγμιότυπων με καθυστέρηση: η καθυστέρηση λαμβάνει χώρα πριν
την εμφάνιση της περιοχής σύλληψης ενώ όταν είναι
απενεργοποιημένο η καθυστέρηση λαμβάνει χώρα μετά την εμφάνιση
της περιοχής σύλληψης. Αυτό το χαρακτηριστικό είναι
απενεργοποιημένο για τον εξυπηρετητή Wayland
και πάντα ενεργοποιημένο για το MacOs.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Εμφάνιση του μεγεθυντικού φακού στην περιοχή σύλληψης</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Εμφανίζει έναν μεγεθυντικό φακό ο οποίος εστιάζει
στην εικόνα του παρασκηνίου. Αυτή η επιλογή λειτουργεί μόνο όταν
το &quot;πάγωμα της οθόνης κατά την σύλληψη&quot; είναι ενεργοποιημένο.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Εμφάνιση των χαράκων στην περιοχή σύλληψης</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Οριζόντιες και κάθετες γραμμές από τις άκρες της επιφάνειας
εργασίας μέχρι τον δρομέα στην περιοχή της σύλληψης.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Εμφάνιση των πληροφοριών θέσης και μεγέθους στην περιοχή σύλληψης</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Όταν το αριστερό κλικ του ποντικιού δεν είναι πιεσμένο, εμφανίζεται η θέση.
Όταν το κλικ του ποντικιού είναι πατημένο,
το μέγεθος της επιλεγμένης περιοχής εμφανίζεται στα
αριστερά και κάτω από την περιοχή σύλληψης.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Να επιτρέπεται η αλλαγή μεγέθους της ορθογώνιας περιοχής επιλογής εξ ορισμού</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Όταν είναι ενεργοποιημένο και αφού έχει επιλεγεί μια
ορθογώνια περιοχή, επιτρέπει την αλλαγή μεγέθους της επιλογής.
Μετά το πέρας της ενέργειας επιβεβαιώστε
πιέζοντας το πλήκτρο Enter.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Εμφάνιση του κειμένου πληροφοριών στην περιοχή σύλληψης</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Χρώμα του δρομέα της περιοχής σύλληψης</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Ορίζει το χρώμα του δρομέα της περιοχής σύλληψης.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Πάχος του δρομέα της περιοχής σύλληψης</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Ορίζει το πάχος του δρομέα της περιοχής σύλληψης.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Περιοχή σύλληψης</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Χρώμα διακόσμησης της περιοχής σύλληψης</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Ορίζει το χρώμα όλων των αντικειμένων διακόσμησης
στην περιοχή σύλληψης.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Διαφάνεια της περιοχής σύλληψης</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Άλφα για το με επιλεγμένο τμήμα της περιοχής σύλληψης.
Με μικρότερη τιμή αποκτάτε περισσότερη διαφάνεια.</translation>
    </message>
    <message>
        <source>Enable Snipping Area offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will apply the configured
offset to the Snipping Area position which
is required when the position is not
correctly calculated. This is sometimes
required with screen scaling enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Πάνω</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Κάτω</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Χρήση των προκαθορισμένων αυτοκόλλητων</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Ρυθμίσεις αυτοκόλλητων</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Αρχεία διανυσματικών εικόνων (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Προσθήκη αυτοκόλλητων</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Εμφάνιση επεξεργαστή</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Εικονίδιο στο πλαίσιο συστήματος</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Όταν είναι ενεργοποιημένο προστίθεται ένα εικονίδιο στο πλαίσιο συστήματος αν υποστηρίζεται από τον
διαχειριστή παραθύρων του λειτουργικού συστήματος. Για να ληφθούν υπόψιν οι αλλαγές, απαιτείται επανεκκίνηση.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Ελαχιστοποίηση στο πλαίσιο συστήματος</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Εκκίνηση ελαχιστοποιημένο στο πλαίσιο συστήματος</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Κλείσιμο στο πλαίσιο συστήματος</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Εμφάνιση επεξεργαστή</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Σύλληψη</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Προκαθορισμένη ενέργεια του εικονιδίου στο πλαίσιο συστήματος</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Η προκαθορισμένη ενέργεια που προκαλείται με αριστερό κλικ στο εικονίδιο του πλαισίου συστήματος.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Ρυθμίσεις του εικονιδίου του πλαισίου συστήματος</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Χρήση μιας ειδικής υπηρεσίας ειδοποιήσεων του πλατύβαθρου</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Όταν είναι ενεργοποιημένο, θα γίνει προσπάθεια χρήσης της ειδικής υπηρεσίας ειδοποιήσεων του πλατύβαθρου,
εφόσον υπάρχει μία. Για να λάβει χώρα η αλλαγή αυτής της ρύθμισης απαιτείται επανεκκίνηση.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Επιλογή εικόνας</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Απαιτείται μια μακροεντολή αποστολής</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Παρακαλώ προσθέστε μια μακροεντολή αποστολής από το μενού Επιλογές &gt; Ρυθμίσεις &gt; Μακροεντολή αποστολής</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Αποστολή της σύλληψης</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Πρόκειται να κάνετε αποστολή της εικόνας σε έναν εξωτερικό προορισμό. Επιθυμείτε να συνεχίσετε;</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Ερώτηση επιβεβαίωσης πριν την αποστολή</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Τύπος αποστολέα:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Μακροεντολή</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Αποστολέας</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Έκδοση</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Κατασκευή</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Γίνεται χρήση:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Εικόνα υδατογραφήματος</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Ενημέρωση</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Περιστροφή υδατογραφήματος</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Όταν είναι ενεργοποιημένο, το υδατογράφημα θα εισαχθεί με περιστροφή 45°</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Ρυθμίσεις υδατογραφήματος</translation>
    </message>
</context>
</TS>
